@@ -12,7 +12,7 @@ var classzypp_1_1media_1_1MediaCurl =
     [ "setCookieFile", "classzypp_1_1media_1_1MediaCurl.html#a0a203b64ae743397e3708cf35ff03f0b", null ],
     [ "aliveCallback", "classzypp_1_1media_1_1MediaCurl.html#aec9f29094109edb2429174d926c92507", null ],
     [ "progressCallback", "classzypp_1_1media_1_1MediaCurl.html#a2dc8bba6cd6830003bb2eceeb140cc1f", null ],
-    [ "progressCallback_getcurl", "classzypp_1_1media_1_1MediaCurl.html#ae362b1521ff48a6fea78a8bb0728e57b", null ],
+    [ "writeCallback", "classzypp_1_1media_1_1MediaCurl.html#a060a612fd8abed83a215519e111f1c13", null ],
     [ "checkProtocol", "classzypp_1_1media_1_1MediaCurl.html#a098264dc45c80a6a725e420fac91c3f0", null ],
     [ "setupEasy", "classzypp_1_1media_1_1MediaCurl.html#af79e22e88deb72cdc0b147df8c1d95ba", null ],
     [ "evaluateCurlCode", "classzypp_1_1media_1_1MediaCurl.html#a70b0d22deee81a942f2d47c9a87875fb", null ],
